@@ -1,11 +1,11 @@
-package Hash::Util::FieldHash::Compat; # git description: v0.08-12-gc264723
+package Hash::Util::FieldHash::Compat; # git description: v0.10-5-g9de9e11
 # ABSTRACT: Use Hash::Util::FieldHash or ties, depending on availability
 # KEYWORDS: fields hashes fieldhash backwards compatibility backcompat tie
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.11';
 
 use constant REAL_FIELDHASH => do { local $@; local $SIG{__DIE__}; eval { require Hash::Util::FieldHash } };
 
@@ -46,7 +46,7 @@ Hash::Util::FieldHash::Compat - Use Hash::Util::FieldHash or ties, depending on
 
 =head1 VERSION
 
-version 0.09
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -71,6 +71,11 @@ See L<Hash::Util::FieldHash> for all the details of the API.
 
 L<Hash::Util::FieldHash>, L<Tie::RefHash>, L<Tie::RefHash::Weak>.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Hash-Util-FieldHash-Compat>
+(or L<bug-Hash-Util-FieldHash-Compat@rt.cpan.org|mailto:bug-Hash-Util-FieldHash-Compat@rt.cpan.org>).
+
 =head1 AUTHOR
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
@@ -81,7 +86,7 @@ L<Hash::Util::FieldHash>, L<Tie::RefHash>, L<Tie::RefHash::Weak>.
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman).
 
